.. expect: role missing (escaped) space after role: ':literal:`:manpage
.. expect: found an unbalanced inline literal markup. (unbalanced-inline-literals-delimiters)

The :literal:`:manpage:`man(1)``s roles...
